@@ -19,7 +19,7 @@
 #ifndef CMYK_U16_PLUGIN_H_
 #define CMYK_U16_PLUGIN_H_
 
-#include <kparts/plugin.h>
+#include <tdeparts/plugin.h>
 
 /**
  * A plugin wrapper around the CMYK U16 colour space strategy.
@@ -27,7 +27,7 @@
 class CMYKU16Plugin : public KParts::Plugin
 {
     Q_OBJECT
-  TQ_OBJECT
+  
 public:
     CMYKU16Plugin(TQObject *parent, const char *name, const TQStringList &);
     virtual ~CMYKU16Plugin();
