@@ -19,7 +19,7 @@
 #ifndef GRAY_PLUGIN_H_
 #define GRAY_PLUGIN_H_
 
-#include <kparts/plugin.h>
+#include <tdeparts/plugin.h>
 
 /**
  * A plugin wrapper around the GRAY colour space strategy.
@@ -27,7 +27,7 @@
 class GrayPlugin : public KParts::Plugin
 {
     Q_OBJECT
-  TQ_OBJECT
+  
 public:
     GrayPlugin(TQObject *parent, const char *name, const TQStringList &);
     virtual ~GrayPlugin();
