@@ -20,7 +20,7 @@
 #ifndef RGB_F32_PLUGIN_H_
 #define RGB_F32_PLUGIN_H_
 
-#include <kparts/plugin.h>
+#include <tdeparts/plugin.h>
 
 /**
  * A plugin wrapper around the RGB F32 colour space strategy.
@@ -28,7 +28,7 @@
 class RGBF32Plugin : public KParts::Plugin
 {
     Q_OBJECT
-  TQ_OBJECT
+  
 public:
     RGBF32Plugin(TQObject *parent, const char *name, const TQStringList &);
     virtual ~RGBF32Plugin();
