@@ -30,9 +30,9 @@
 #include <tqrect.h>
 
 #include <kdebug.h>
-#include <kaction.h>
+#include <tdeaction.h>
 #include <kcommand.h>
-#include <klocale.h>
+#include <tdelocale.h>
 #include <knuminput.h>
 #include <kdebug.h>
 
@@ -701,7 +701,7 @@ void KisToolCrop::setOptionWidgetRatio(double ratio)
 TQWidget* KisToolCrop::createOptionWidget(TQWidget* parent)
 {
     m_optWidget = new WdgToolCrop(parent);
-    Q_CHECK_PTR(m_optWidget);
+    TQ_CHECK_PTR(m_optWidget);
 
     connect(m_optWidget->bnCrop, TQT_SIGNAL(clicked()), this, TQT_SLOT(crop()));
 
@@ -719,19 +719,19 @@ TQWidget* KisToolCrop::optionWidget()
     return m_optWidget;
 }
 
-void KisToolCrop::setup(KActionCollection *collection)
+void KisToolCrop::setup(TDEActionCollection *collection)
 {
-    m_action = static_cast<KRadioAction *>(collection->action(name()));
+    m_action = static_cast<TDERadioAction *>(collection->action(name()));
 
     if (m_action == 0) {
-        m_action = new KRadioAction(i18n("&Crop"),
+        m_action = new TDERadioAction(i18n("&Crop"),
                                     "tool_crop",
                                     0,
                                     this,
                                     TQT_SLOT(activate()),
                                     collection,
                                     name());
-        Q_CHECK_PTR(m_action);
+        TQ_CHECK_PTR(m_action);
 
         m_action->setToolTip(i18n("Crop an area"));
         m_action->setExclusiveGroup("tools");
