@@ -33,9 +33,9 @@
 #include <tqapplication.h>
 
 #include <kdebug.h>
-#include <kaction.h>
+#include <tdeaction.h>
 #include <kcommand.h>
-#include <klocale.h>
+#include <tdelocale.h>
 #include <knuminput.h>
 
 #include <kis_global.h>
@@ -685,7 +685,7 @@ TQWidget* KisToolPerspectiveTransform::createOptionWidget(TQWidget* /*parent*/)
 {
 #if 0
     m_optWidget = new WdgToolPerspectiveTransform(parent);
-    Q_CHECK_PTR(m_optWidget);
+    TQ_CHECK_PTR(m_optWidget);
 
     m_optWidget->cmbFilter->clear();
     m_optWidget->cmbFilter->setIDList(KisFilterStrategyRegistry::instance()->listKeys());
@@ -720,19 +720,19 @@ TQWidget* KisToolPerspectiveTransform::optionWidget()
     return 0;
 }
 
-void KisToolPerspectiveTransform::setup(KActionCollection *collection)
+void KisToolPerspectiveTransform::setup(TDEActionCollection *collection)
 {
-    m_action = static_cast<KRadioAction *>(collection->action(name()));
+    m_action = static_cast<TDERadioAction *>(collection->action(name()));
 
     if (m_action == 0) {
-        m_action = new KRadioAction(i18n("&Perspective Transform"),
+        m_action = new TDERadioAction(i18n("&Perspective Transform"),
                         "tool_perspectivetransform",
                         0,
                         this,
                         TQT_SLOT(activate()),
                         collection,
                         name());
-        Q_CHECK_PTR(m_action);
+        TQ_CHECK_PTR(m_action);
         m_action->setToolTip(i18n("Perspective transform a layer or a selection"));
         m_action->setExclusiveGroup("tools");
         m_ownAction = true;
