@@ -20,7 +20,7 @@
 #ifndef IMAGESIZE_H
 #define IMAGESIZE_H
 
-#include <kparts/plugin.h>
+#include <tdeparts/plugin.h>
 
 class KisView;
 class KisPainter;
@@ -28,7 +28,7 @@ class KisPainter;
 class ImageSize : public KParts::Plugin
 {
     Q_OBJECT
-  TQ_OBJECT
+  
 public:
     ImageSize(TQObject *parent, const char *name, const TQStringList &);
     virtual ~ImageSize();
