@@ -30,13 +30,13 @@
 #include <tqtextedit.h>
 #include <tqdatetime.h>
 
-#include <klocale.h>
+#include <tdelocale.h>
 #include <kiconloader.h>
 #include <kinstance.h>
 #include <kdialogbase.h>
-#include <kmessagebox.h>
+#include <tdemessagebox.h>
 #include <kstandarddirs.h>
-#include <ktempfile.h>
+#include <tdetempfile.h>
 #include <kdebug.h>
 #include <kgenericfactory.h>
 #include <knuminput.h>
@@ -86,7 +86,7 @@ PerfTest::PerfTest(TQObject *parent, const char *name, const TQStringList &)
         setInstance(PerfTestFactory::instance());
         setXMLFile(locate("data","chalkplugins/perftest.rc"), true);
 
-        (void) new KAction(i18n("&Performance Test..."), 0, 0, this, TQT_SLOT(slotPerfTest()), actionCollection(), "perf_test");
+        (void) new TDEAction(i18n("&Performance Test..."), 0, 0, this, TQT_SLOT(slotPerfTest()), actionCollection(), "perf_test");
 
         m_view = (KisView*) parent;
     }
@@ -104,7 +104,7 @@ void PerfTest::slotPerfTest()
     if (!image) return;
 
     DlgPerfTest * dlgPerfTest = new DlgPerfTest(m_view, "PerfTest");
-    Q_CHECK_PTR(dlgPerfTest);
+    TQ_CHECK_PTR(dlgPerfTest);
 
     dlgPerfTest->setCaption(i18n("Performance Test"));
 
@@ -217,11 +217,11 @@ void PerfTest::slotPerfTest()
             kdDebug() << s << "\n";
         }
         KDialogBase * d = new KDialogBase(m_view, "", true, "", KDialogBase::Ok);
-        Q_CHECK_PTR(d);
+        TQ_CHECK_PTR(d);
 
         d->setCaption("Performance test results");
         TQTextEdit * e = new TQTextEdit(d);
-        Q_CHECK_PTR(e);
+        TQ_CHECK_PTR(e);
         d->setMainWidget(e);
         e->setText(report);
         e->setMinimumWidth(600);
@@ -279,7 +279,7 @@ TQString PerfTest::doBlit(const KisCompositeOp& op,
     // Small
 
     KisPaintDeviceSP small = new KisPaintDevice(KisMetaRegistry::instance()->csRegistry()->getColorSpace(cspace,""), "small blit");
-    Q_CHECK_PTR(small);
+    TQ_CHECK_PTR(small);
 
     KisFillPainter pf(small.data()) ;
     pf.fillRect(0, 0, 32, 32, KisColor(TQt::black, KisMetaRegistry::instance()->csRegistry()->getRGB8()));
@@ -302,7 +302,7 @@ TQString PerfTest::doBlit(const KisCompositeOp& op,
     // ------------------------------------------------------------------------------
     // Medium
     KisPaintDeviceSP medium = new KisPaintDevice(KisMetaRegistry::instance()->csRegistry()->getColorSpace(cspace,""), "medium blit");
-    Q_CHECK_PTR(medium);
+    TQ_CHECK_PTR(medium);
 
     pf.begin(medium.data()) ;
     pf.fillRect(0, 0, 64 * 3, 64 * 3, KisColor(TQt::black, KisMetaRegistry::instance()->csRegistry()->getRGB8()));
@@ -325,7 +325,7 @@ TQString PerfTest::doBlit(const KisCompositeOp& op,
     // ------------------------------------------------------------------------------
     // Big
     KisPaintDeviceSP big = new KisPaintDevice(KisMetaRegistry::instance()->csRegistry()->getColorSpace(cspace,""), "big blit");
-    Q_CHECK_PTR(big);
+    TQ_CHECK_PTR(big);
 
     pf.begin(big.data()) ;
     pf.fillRect(0, 0, 800, 800, KisColor(TQt::black, KisMetaRegistry::instance()->csRegistry()->getRGB8()));
@@ -349,7 +349,7 @@ TQString PerfTest::doBlit(const KisCompositeOp& op,
     // Outside
 
     KisPaintDeviceSP outside = new KisPaintDevice(KisMetaRegistry::instance()->csRegistry()->getColorSpace(cspace,""), "outside blit");
-    Q_CHECK_PTR(outside);
+    TQ_CHECK_PTR(outside);
     pf.begin(outside.data()) ;
     pf.fillRect(0, 0, 500, 500, KisColor(TQt::black, KisMetaRegistry::instance()->csRegistry()->getRGB8()));
     pf.end();
@@ -371,7 +371,7 @@ TQString PerfTest::doBlit(const KisCompositeOp& op,
     // Small with varied source opacity
 
     KisPaintDeviceSP small_with_alpha = new KisPaintDevice(KisMetaRegistry::instance()->csRegistry()->getColorSpace(cspace,""), "small blit with alpha");
-    Q_CHECK_PTR(small_with_alpha);
+    TQ_CHECK_PTR(small_with_alpha);
 
     pf.begin(small_with_alpha.data()) ;
     pf.fillRect(0, 0, 32, 32, KisColor(TQt::black, KisMetaRegistry::instance()->csRegistry()->getRGB8()), OPACITY_TRANSPARENT);
@@ -499,7 +499,7 @@ TQString PerfTest::fillTest(TQ_UINT32 testCount)
 //             p.paintEllipse(500, 1000, 100, 0, 0);
             p.setPaintColor(KisColor(TQt::black, KisMetaRegistry::instance()->csRegistry()->getRGB8()));
             KisResourceServerBase* r = KisResourceServerRegistry::instance()->get("PatternServer");
-            Q_CHECK_PTR(r);
+            TQ_CHECK_PTR(r);
             p.setPattern((KisPattern*)r->resources().first());
             p.setFillThreshold(15);
             p.setCompositeOp(COMPOSITE_OVER);
@@ -704,7 +704,7 @@ TQString PerfTest::readBytesTest(TQ_UINT32 testCount)
 
     for (TQ_UINT32 i = 0; i < testCount; ++i) {
         TQ_UINT8 * newData = new TQ_UINT8[1000 * 1000 * l->pixelSize()];
-        Q_CHECK_PTR(newData);
+        TQ_CHECK_PTR(newData);
         l->readBytes(newData, 0, 0, 1000, 1000);
         delete[] newData;
     }
@@ -721,7 +721,7 @@ TQString PerfTest::readBytesTest(TQ_UINT32 testCount)
 
     for (TQ_UINT32 i = 0; i < testCount; ++i) {
         TQ_UINT8 * newData = new TQ_UINT8[1000 * 1000 * l->pixelSize()];
-        Q_CHECK_PTR(newData);
+        TQ_CHECK_PTR(newData);
         l->readBytes(newData, 0, 0, 1000, 1000);
         delete[] newData;
     }
@@ -746,7 +746,7 @@ TQString PerfTest::writeBytesTest(TQ_UINT32 testCount)
 
 
     TQ_UINT8 * data = new TQ_UINT8[1000 * 1000 * l->pixelSize()];
-    Q_CHECK_PTR(data);
+    TQ_CHECK_PTR(data);
     l->readBytes(data, 0, 0, 1000, 1000);
 
     TQTime t;
