@@ -35,7 +35,7 @@
 #include <wv2/parserfactory.h>
 #include <wv2/paragraphproperties.h>
 #include <wv2/associatedstrings.h>
-#include <klocale.h>
+#include <tdelocale.h>
 #include <KoStore.h>
 #include <KoFilterChain.h>
 
