@@ -32,7 +32,7 @@
 #include <tqfont.h>
 #include <tqfontinfo.h>
 #include <kdebug.h>
-#include <klocale.h>
+#include <tdelocale.h>
 
 
 wvWare::U8 KWordReplacementHandler::hardLineBreak()
