@@ -1,4 +1,4 @@
-/* -*- Mode: C++ -*-
+/*
    KDChart - a multi-platform charting engine
 */
 
@@ -140,27 +140,27 @@ class KDCHART_EXPORT KDChartParams : public TQObject
 {
 
     Q_OBJECT
-  TQ_OBJECT
-    Q_ENUMS(ChartType)
-    Q_ENUMS(SourceMode)
-    Q_ENUMS(BarChartSubType)
-    Q_ENUMS(LineChartSubType)
-    Q_ENUMS(LineMarkerStyle)
-    Q_ENUMS(AreaChartSubType)
-    Q_ENUMS(AreaLocation)
-    Q_ENUMS(PolarChartSubType)
-    Q_ENUMS(PolarMarkerStyle)
-    Q_ENUMS(HiLoChartSubType)
-    Q_ENUMS(BWChartSubType)
-    Q_ENUMS(BWStatVal)
-    Q_ENUMS(LegendPosition)
-    Q_ENUMS(LegendSource)
-    Q_ENUMS(HdFtPos)
+  
+    TQ_ENUMS(ChartType)
+    TQ_ENUMS(SourceMode)
+    TQ_ENUMS(BarChartSubType)
+    TQ_ENUMS(LineChartSubType)
+    TQ_ENUMS(LineMarkerStyle)
+    TQ_ENUMS(AreaChartSubType)
+    TQ_ENUMS(AreaLocation)
+    TQ_ENUMS(PolarChartSubType)
+    TQ_ENUMS(PolarMarkerStyle)
+    TQ_ENUMS(HiLoChartSubType)
+    TQ_ENUMS(BWChartSubType)
+    TQ_ENUMS(BWStatVal)
+    TQ_ENUMS(LegendPosition)
+    TQ_ENUMS(LegendSource)
+    TQ_ENUMS(HdFtPos)
 
     // Needed for TQSA
-    Q_ENUMS( BrushStyle )
-    Q_ENUMS( PenStyle )
-    Q_ENUMS( Orientation )
+    TQ_ENUMS( BrushStyle )
+    TQ_ENUMS( PenStyle )
+    TQ_ENUMS( Orientation )
 
 
 public slots: // PENDING(blackie) merge public slots into one section.
@@ -227,7 +227,7 @@ public:
     class KDCHART_EXPORT KDChartFrameSettings
     {
         // Q_OBJECT
-        // TQ_OBJECT
+        // 
     public:
         KDChartFrameSettings();
         KDChartFrameSettings( uint           dataRow,
