@@ -33,10 +33,10 @@
 #include <tqlabel.h>
 #include <tqpainter.h>
 
-#include <kfiledialog.h>
-#include <klocale.h>
+#include <tdefiledialog.h>
+#include <tdelocale.h>
 #include <kcommand.h>
-#include <kaccelmanager.h>
+#include <tdeaccelmanager.h>
 
 #include "form.h"
 #include "container.h"
@@ -1197,11 +1197,11 @@ FormIO::loadWidget(Container *container, const TQDomElement &el, TQWidget *paren
 
 	if(!w)
 		return;
-#if KDE_VERSION >= KDE_MAKE_VERSION(3,4,0) 
+#if TDE_VERSION >= TDE_MAKE_VERSION(3,4,0) 
 //! @todo allow setting this for data view mode as well
 	if (m_currentForm->designMode()) {
 		//don't generate accelerators for widgets in design mode
-		KAcceleratorManager::setNoAccel(w);
+		TDEAcceleratorManager::setNoAccel(w);
 	}
 #endif
 	w->setStyle(&(container->widget()->style()));
