@@ -29,10 +29,10 @@
 #include <tqbuffer.h>
 
 #include <kdebug.h>
-#include <klocale.h>
+#include <tdelocale.h>
 #include <kstaticdeleter.h>
-#include <kmessagebox.h>
-#include <klocale.h>
+#include <tdemessagebox.h>
+#include <tdelocale.h>
 #include <kiconloader.h>
 
 #include "utils_p.h"
@@ -613,12 +613,12 @@ TQString KexiDB::formatNumberForVisibleDecimalPlaces(double value, int decimalPl
 			i--;
 		if (s[i]=='.') //remove '.'
 			i--;
-		s = s.left(i+1).replace('.', KGlobal::locale()->decimalSymbol());
+		s = s.left(i+1).replace('.', TDEGlobal::locale()->decimalSymbol());
 		return s;
 	}
 	if (decimalPlaces == 0)
 		return TQString::number((int)value);
-	return KGlobal::locale()->formatNumber(value, decimalPlaces);
+	return TDEGlobal::locale()->formatNumber(value, decimalPlaces);
 }
 
 KexiDB::Field::Type KexiDB::intToFieldType( int type )
@@ -1032,7 +1032,7 @@ TQVariant KexiDB::notEmptyValueForType( KexiDB::Field::Type type )
 				TQByteArray ba;
 				TQBuffer buffer( ba );
 				buffer.open( IO_WriteOnly );
-				TQPixmap pm(SmallIcon("filenew"));
+				TQPixmap pm(SmallIcon("document-new"));
 				pm.save( &buffer, "PNG"/*! @todo default? */ );
 				ADD(i, ba);
 				continue;
