@@ -25,16 +25,16 @@
 #include <kexiutils/utils.h>
 #include <kexi_version.h>
 
-#include <kapplication.h>
+#include <tdeapplication.h>
 #include <kiconloader.h>
-#include <klocale.h>
-#include <kfontdialog.h>
+#include <tdelocale.h>
+#include <tdefontdialog.h>
 #include <kurllabel.h>
 #include <kdebug.h>
 #include <klineedit.h>
 #include <kprinter.h>
 #include <kpushbutton.h>
-#include <kdeversion.h>
+#include <tdeversion.h>
 
 #include <tqlabel.h>
 #include <tqtimer.h>
@@ -324,7 +324,7 @@ KexiSimplePrintingPageSetup::KexiSimplePrintingPageSetup( KexiMainWindow *mainWi
 
 	// settings
 //! @todo default?
-	m_unit = KLocale::Metric == KGlobal::locale()->measureSystem() ? KoUnit::U_CM : KoUnit::U_INCH;
+	m_unit = TDELocale::Metric == TDEGlobal::locale()->measureSystem() ? KoUnit::U_CM : KoUnit::U_INCH;
 
 	// GUI
 	TQVBoxLayout *lyr = new TQVBoxLayout(this);
@@ -335,16 +335,16 @@ KexiSimplePrintingPageSetup::KexiSimplePrintingPageSetup( KexiMainWindow *mainWi
 //	setFocusPolicy(WheelFocus);
 	m_contents->setFocusProxy(m_contents->headerTitleLineEdit);
 
-	m_contents->printButton->setIconSet( KStdGuiItem::print().iconSet(KIcon::Small) );
+	m_contents->printButton->setIconSet( KStdGuiItem::print().iconSet(TDEIcon::Small) );
 	m_contents->printButton->setText( KStdGuiItem::print().text() );
 	connect(m_contents->printButton, TQT_SIGNAL(clicked()), this, TQT_SLOT(print()));
 
-	m_contents->printPreviewButton->setIconSet( SmallIconSet("filequickprint") );
+	m_contents->printPreviewButton->setIconSet( SmallIconSet("document-print-preview") );
 	m_contents->printPreviewButton->setText( i18n("Print Previe&w...") );
 	connect(m_contents->printPreviewButton, TQT_SIGNAL(clicked()), this, TQT_SLOT(printPreview()));
 
 	m_contents->iconLabel->setFixedWidth(32+6);
-	m_contents->iconLabel->setPixmap( DesktopIcon("document", 32) );
+	m_contents->iconLabel->setPixmap( DesktopIcon("text-x-generic", 32) );
 	TQWhatsThis::add(m_contents->headerTitleFontButton, i18n("Changes font for title text."));
 	connect(m_contents->headerTitleFontButton, TQT_SIGNAL(clicked()), 
 		this, TQT_SLOT(slotChangeTitleFont()));
@@ -501,7 +501,7 @@ void KexiSimplePrintingPageSetup::slotTitleTextChanged(const TQString&)
 
 void KexiSimplePrintingPageSetup::slotChangeTitleFont()
 {
-	if (TQDialog::Accepted != KFontDialog::getFont(m_settings.pageTitleFont, false, this))
+	if (TQDialog::Accepted != TDEFontDialog::getFont(m_settings.pageTitleFont, false, this))
 		return;
 	m_contents->headerTitleLineEdit->setFont( m_settings.pageTitleFont );
 	setDirty(true);
