@@ -40,10 +40,10 @@
 #include <tqlayout.h>
 #include <tqhgroupbox.h>
 
-#include <kapplication.h>
+#include <tdeapplication.h>
 #include <kdebug.h>
-#include <klocale.h>
-#include <kmessagebox.h>
+#include <tdelocale.h>
+#include <tdemessagebox.h>
 
 using namespace KSpread;
 
