@@ -32,7 +32,7 @@
 
 #include <tqregexp.h>
 
-#include <kconfig.h>
+#include <tdeconfig.h>
 #include <kdebug.h>
 
 #include "kspread_doc.h"
@@ -201,7 +201,7 @@ AutoFillSequenceItem::AutoFillSequenceItem( const TQString &_str )
     if( other==0L)
       {
 	//	other=new TQStringList();
-	KConfig *config = Factory::global()->config();
+	TDEConfig *config = Factory::global()->config();
 	config->setGroup( "Parameters" );
 	other=new TQStringList(config->readListEntry("Other list"));
       }
