@@ -21,7 +21,7 @@
 #include <tqbuffer.h>
 
 #include <kdebug.h>
-#include <klocale.h>
+#include <tdelocale.h>
 
 #include <KoGlobal.h>
 #include <KoGenStyles.h>
@@ -586,8 +586,8 @@ static TQString convertDateFormat( const TQString& date )
 
 FormatType Style::dateType( const TQString &_format )
 {
-    const TQString dateFormatShort = convertDateFormat( KGlobal::locale()->dateFormatShort() );
-    const TQString dateFormat = convertDateFormat( KGlobal::locale()->dateFormat() );
+    const TQString dateFormatShort = convertDateFormat( TDEGlobal::locale()->dateFormatShort() );
+    const TQString dateFormat = convertDateFormat( TDEGlobal::locale()->dateFormat() );
 
     if ( _format == "dd-MMM-yy" )
         return date_format1;
@@ -899,11 +899,11 @@ TQString Style::saveOasisStyleNumericDate( KoGenStyles&mainStyles, FormatType _s
     {
         //TODO fixme use locale of kspread and not kglobal
     case ShortDate_format:
-        format = KGlobal::locale()->dateFormatShort();
+        format = TDEGlobal::locale()->dateFormatShort();
         locale = true;
         break;
     case TextDate_format:
-        format = KGlobal::locale()->dateFormat();
+        format = TDEGlobal::locale()->dateFormat();
         locale = true;
         break;
     case date_format1:
