@@ -29,7 +29,7 @@
 #include <tqpushbutton.h>
 #include <tqlineedit.h>
 #include <tqvalidator.h>
-#include <klocale.h>
+#include <tdelocale.h>
 #include <kdebug.h>
 #include <tqtoolbutton.h>
 #include <tqtooltip.h>
@@ -46,7 +46,7 @@
  *
  ******************************************************************/
 
-KWClassicSerialDataSource::KWClassicSerialDataSource(KInstance *inst,TQObject *parent)
+KWClassicSerialDataSource::KWClassicSerialDataSource(TDEInstance *inst,TQObject *parent)
 	: KWMailMergeDataSource(inst,parent)
 //    : doc( doc_ )
 {
@@ -341,7 +341,7 @@ KWClassicMailMergeEditor::KWClassicMailMergeEditor( TQWidget *parent, KWClassicS
     TQHBox *toolbar = new TQHBox( back );
 
     first = new TQToolButton( toolbar );
-    first->setIconSet( SmallIconSet( "start" ) );
+    first->setIconSet( SmallIconSet( "go-first" ) );
     first->setFixedSize( first->sizeHint() );
     connect(first, TQT_SIGNAL(clicked()), this, TQT_SLOT(firstRecord()));
 
@@ -361,7 +361,7 @@ KWClassicMailMergeEditor::KWClassicMailMergeEditor( TQWidget *parent, KWClassicS
     connect(forward, TQT_SIGNAL(clicked()), this, TQT_SLOT(nextRecord()));
 
     finish = new TQToolButton( toolbar );
-    finish->setIconSet( SmallIconSet( "finish" ) );
+    finish->setIconSet( SmallIconSet( "go-last" ) );
     finish->setFixedSize( finish->sizeHint() );
     connect(finish, TQT_SIGNAL(clicked()), this, TQT_SLOT(lastRecord()));
 
@@ -561,7 +561,7 @@ void KWClassicMailMergeEditor::removeRecord()
 }
 
 extern "C" {
-	KWORD_MAILMERGE_EXPORT KWMailMergeDataSource *create_kwmailmerge_classic(KInstance *inst,TQObject *parent)
+	KWORD_MAILMERGE_EXPORT KWMailMergeDataSource *create_kwmailmerge_classic(TDEInstance *inst,TQObject *parent)
 	{
 		return new KWClassicSerialDataSource(inst,parent);
 	}
