@@ -24,11 +24,11 @@
 #include <tqapplication.h>
 
 #include <kstaticdeleter.h>
-#include <klocale.h>
+#include <tdelocale.h>
 #include <kstandarddirs.h>
-#include <kio/netaccess.h>
-#include <kio/job.h>
-#include <kmessagebox.h>
+#include <tdeio/netaccess.h>
+#include <tdeio/job.h>
+#include <tdemessagebox.h>
 
 #include "fontstyle.h"
 
@@ -118,21 +118,21 @@ void FontStyle::installFonts()
         for (TQStringList::iterator it = missing.begin(); it != missing.end(); ++it)
         {
             if ( *it == "arev sans" ) {
-                if (!KIO::NetAccess::exists("fonts:/Personal/Arev.ttf", true, NULL))
+                if (!TDEIO::NetAccess::exists("fonts:/Personal/Arev.ttf", true, NULL))
                     urlList.append(locate("data", "kformula/fonts/Arev.ttf"));
-                if (!KIO::NetAccess::exists("fonts:/Personal/ArevIt.ttf", true, NULL))
+                if (!TDEIO::NetAccess::exists("fonts:/Personal/ArevIt.ttf", true, NULL))
                     urlList.append(locate("data", "kformula/fonts/ArevIt.ttf"));
-                if (!KIO::NetAccess::exists("fonts:/Personal/ArevBd.ttf", true, NULL))
+                if (!TDEIO::NetAccess::exists("fonts:/Personal/ArevBd.ttf", true, NULL))
                     urlList.append(locate("data", "kformula/fonts/ArevBd.ttf"));
-                if (!KIO::NetAccess::exists("fonts:/Personal/ArevBI.ttf", true, NULL))
+                if (!TDEIO::NetAccess::exists("fonts:/Personal/ArevBI.ttf", true, NULL))
                     urlList.append(locate("data", "kformula/fonts/ArevBI.ttf"));
             }
             else {
-                if (!KIO::NetAccess::exists("fonts:/Personal/" + *it + ".ttf", true, NULL))
+                if (!TDEIO::NetAccess::exists("fonts:/Personal/" + *it + ".ttf", true, NULL))
                     urlList.append(locate("data", "kformula/fonts/" + *it + ".ttf"));
             }
         }
-        KIO::copy(urlList, "fonts:/Personal/", false);
+        TDEIO::copy(urlList, "fonts:/Personal/", false);
         KMessageBox::information(tqApp->mainWidget(), 
                                  i18n("Some fonts have been installed to assure that symbols in formulas are properly visualized. You must restart the application in order so that changes take effect"));
     }
