@@ -19,7 +19,7 @@
 #ifndef __koDocument_p_h__
 #define __koDocument_p_h__
 
-#include <kparts/browserextension.h>
+#include <tdeparts/browserextension.h>
 
 class KoDocument;
 
@@ -30,7 +30,7 @@ class KoDocument;
 class KoBrowserExtension : public KParts::BrowserExtension
 {
     Q_OBJECT
-  TQ_OBJECT
+  
 public:
     KoBrowserExtension( KoDocument * doc, const char * name = 0 );
 
