@@ -44,9 +44,9 @@
 #include "KoParagCounter.h"
 #include "KoTextDocument.h"
 #include <kdebug.h>
-#include <kdeversion.h>
-#include <kglobal.h>
-#include <klocale.h>
+#include <tdeversion.h>
+#include <tdeglobal.h>
+#include <tdelocale.h>
 #include <tqtextengine_p.h>
 
 //#define DEBUG_COLLECTION
